==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ImageBackgroundType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds an image as a background layer to the document.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ImageBackgroundType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ImageBackgroundType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BackgroundBaseType">
 *       <all>
 *         <element name="settings" type="{http://schema.webpdf.de/1.0/operation}BackgroundBaseSettingsType" minOccurs="0"/>
 *         <element name="image" type="{http://schema.webpdf.de/1.0/operation}BackgroundFileDataType"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ImageBackgroundType", propOrder = {
    "settings",
    "image"
})
public class ImageBackgroundType
    extends BackgroundBaseType
{

    protected BackgroundBaseSettingsType settings;
    @XmlElement(required = true)
    protected BackgroundFileDataType image;

    /**
     * Gets the value of the settings property.
     * 
     * @return
     *     possible object is
     *     {@link BackgroundBaseSettingsType }
     *     
     */
    public BackgroundBaseSettingsType getSettings() {
        return settings;
    }

    /**
     * Sets the value of the settings property.
     * 
     * @param value
     *     allowed object is
     *     {@link BackgroundBaseSettingsType }
     *     
     */
    public void setSettings(BackgroundBaseSettingsType value) {
        this.settings = value;
    }

    public boolean isSetSettings() {
        return (this.settings!= null);
    }

    /**
     * Gets the value of the image property.
     * 
     * @return
     *     possible object is
     *     {@link BackgroundFileDataType }
     *     
     */
    public BackgroundFileDataType getImage() {
        return image;
    }

    /**
     * Sets the value of the image property.
     * 
     * @param value
     *     allowed object is
     *     {@link BackgroundFileDataType }
     *     
     */
    public void setImage(BackgroundFileDataType value) {
        this.image = value;
    }

    public boolean isSetImage() {
        return (this.image!= null);
    }

}

==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ImageBackgroundType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds an image as a background layer to the document.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ImageBackgroundType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ImageBackgroundType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BackgroundBaseType">
 *       <all>
 *         <element name="settings" type="{http://schema.webpdf.de/1.0/operation}BackgroundBaseSettingsType" minOccurs="0"/>
 *         <element name="image" type="{http://schema.webpdf.de/1.0/operation}BackgroundFileDataType"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ImageBackgroundType", propOrder = {
    "settings",
    "image"
})
public class ImageBackgroundType
    extends BackgroundBaseType
{

    protected BackgroundBaseSettingsType settings;
    @XmlElement(required = true)
    protected BackgroundFileDataType image;

    /**
     * Gets the value of the settings property.
     * 
     * @return
     *     possible object is
     *     {@link BackgroundBaseSettingsType }
     *     
     */
    public BackgroundBaseSettingsType getSettings() {
        return settings;
    }

    /**
     * Sets the value of the settings property.
     * 
     * @param value
     *     allowed object is
     *     {@link BackgroundBaseSettingsType }
     *     
     */
    public void setSettings(BackgroundBaseSettingsType value) {
        this.settings = value;
    }

    public boolean isSetSettings() {
        return (this.settings!= null);
    }

    /**
     * Gets the value of the image property.
     * 
     * @return
     *     possible object is
     *     {@link BackgroundFileDataType }
     *     
     */
    public BackgroundFileDataType getImage() {
        return image;
    }

    /**
     * Sets the value of the image property.
     * 
     * @param value
     *     allowed object is
     *     {@link BackgroundFileDataType }
     *     
     */
    public void setImage(BackgroundFileDataType value) {
        this.image = value;
    }

    public boolean isSetImage() {
        return (this.image!= null);
    }

}
